
#ifndef _C13_kl625_
#define _C13_kl625_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_REFERENCE F1423_13367(EIF_REFERENCE);
extern void EIF_Minit625(void);
extern EIF_REFERENCE F1_14(EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif
